"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
function _export(target, all) {
    for(var name in all)Object.defineProperty(target, name, {
        enumerable: true,
        get: all[name]
    });
}
_export(exports, {
    ToolbarPlugin: function() {
        return ToolbarPlugin;
    },
    default: function() {
        return _default;
    }
});
const _define_property = require("@swc/helpers/_/_define_property");
const _view = require("@codemirror/view");
const _dom = require("./libs/dom");
let ToolbarPlugin = class ToolbarPlugin {
    handleClick(e) {
        const target = e.target;
        if (target && target.tagName === 'BUTTON') {
            const cmd = target.dataset.item;
            if (cmd) {
                const command = this.handlers[cmd];
                if (command) {
                    e.preventDefault();
                    e.stopPropagation();
                    command(this.view);
                    return;
                }
            }
        }
        this.view.focus();
    }
    destroy() {
        this.element.remove();
    }
    constructor(view, config){
        _define_property._(this, "view", void 0);
        _define_property._(this, "element", void 0);
        _define_property._(this, "config", void 0);
        _define_property._(this, "handlers", void 0);
        this.view = view;
        this.handlers = {};
        this.config = {
            ...config,
            items: config.items.map((item, index)=>{
                if ('type' in item) {
                    return {
                        ...item
                    };
                }
                const key = item.key || item.command.displayName || item.command?.name || `cmd_${index}`;
                this.handlers[key] = item.command;
                return {
                    ...item,
                    key
                };
            })
        };
        const element = this.element = (0, _dom.createElement)(this.config);
        element.addEventListener('click', this.handleClick.bind(this));
        this.view.dom.prepend(element);
    }
};
const plugin = (config)=>{
    return _view.ViewPlugin.define((view)=>new ToolbarPlugin(view, config));
};
const _default = plugin;
