import { _ as _define_property } from "@swc/helpers/_/_define_property";
import { ViewPlugin } from '@codemirror/view';
import { createElement } from './libs/dom';
export class ToolbarPlugin {
    handleClick(e) {
        const target = e.target;
        if (target && target.tagName === 'BUTTON') {
            const cmd = target.dataset.item;
            if (cmd) {
                const command = this.handlers[cmd];
                if (command) {
                    e.preventDefault();
                    e.stopPropagation();
                    command(this.view);
                    return;
                }
            }
        }
        this.view.focus();
    }
    destroy() {
        this.element.remove();
    }
    constructor(view, config){
        _define_property(this, "view", void 0);
        _define_property(this, "element", void 0);
        _define_property(this, "config", void 0);
        _define_property(this, "handlers", void 0);
        this.view = view;
        this.handlers = {};
        this.config = {
            ...config,
            items: config.items.map((item, index)=>{
                if ('type' in item) {
                    return {
                        ...item
                    };
                }
                const key = item.key || item.command.displayName || item.command?.name || `cmd_${index}`;
                this.handlers[key] = item.command;
                return {
                    ...item,
                    key
                };
            })
        };
        const element = this.element = createElement(this.config);
        element.addEventListener('click', this.handleClick.bind(this));
        this.view.dom.prepend(element);
    }
}
const plugin = (config)=>{
    return ViewPlugin.define((view)=>new ToolbarPlugin(view, config));
};
export default plugin;
